@@ -81,7 +81,7 @@ Rmpz_init2_nobless Rmpz_init_nobless Rmpz_init_set Rmpz_init_set_d
 Rmpz_init_set_d_nobless Rmpz_init_set_nobless Rmpz_init_set_si
 Rmpz_init_set_si_nobless Rmpz_init_set_str Rmpz_init_set_str_nobless
 Rmpz_init_set_ui Rmpz_init_set_ui_nobless Rmpz_inp_str Rmpz_inp_raw
-Rmpz_invert Rmpz_ior
+Rmpz_invert Rmpz_ior new_from_MBI
 Rmpz_jacobi Rmpz_kronecker Rmpz_kronecker_si Rmpz_kronecker_ui Rmpz_lcm
 Rmpz_lcm_ui Rmpz_legendre Rmpz_lucnum2_ui Rmpz_lucnum_ui Rmpz_mod Rmpz_mod_ui
 Rmpz_mul Rmpz_mul_2exp Rmpz_mul_si Rmpz_mul_ui Rmpz_neg Rmpz_nextprime
@@ -104,7 +104,7 @@ zgmp_randinit_set zgmp_randinit_default_nobless zgmp_randinit_mt_nobless
 zgmp_randinit_lc_2exp_nobless zgmp_randinit_lc_2exp_size_nobless zgmp_randinit_set_nobless
 zgmp_urandomb_ui zgmp_urandomm_ui
     );
-    our $VERSION = '0.42';
+    our $VERSION = '0.43';
     #$VERSION = eval $VERSION;
 
     DynaLoader::bootstrap Math::GMPz $VERSION;
@@ -132,7 +132,7 @@ Rmpz_init2_nobless Rmpz_init_nobless Rmpz_init_set Rmpz_init_set_d
 Rmpz_init_set_d_nobless Rmpz_init_set_nobless Rmpz_init_set_si
 Rmpz_init_set_si_nobless Rmpz_init_set_str Rmpz_init_set_str_nobless
 Rmpz_init_set_ui Rmpz_init_set_ui_nobless Rmpz_inp_str Rmpz_inp_raw
-Rmpz_invert Rmpz_ior
+Rmpz_invert Rmpz_ior new_from_MBI
 Rmpz_jacobi Rmpz_kronecker Rmpz_kronecker_si Rmpz_kronecker_ui Rmpz_lcm
 Rmpz_lcm_ui Rmpz_legendre Rmpz_lucnum2_ui Rmpz_lucnum_ui Rmpz_mod Rmpz_mod_ui
 Rmpz_mul Rmpz_mul_2exp Rmpz_mul_si Rmpz_mul_ui Rmpz_neg Rmpz_nextprime
@@ -224,6 +224,18 @@ sub new {
       if(@_) {die "Too many arguments supplied to new() - expected only one"}
       return Rmpz_init_set($arg1);
     }
+
+    if($type == -1) { # Math::BigInt
+      if(@_) {die "Too many arguments supplied to new() - expected only one"}
+      return _new_from_MBI($arg1);
+    }
+
+    die "Unrecognised argument provided to new()";
+}
+
+sub new_from_MBI {
+    return _new_from_MBI($_[0]) if _itsa($_[0]) == -1;
+    die "Inappropriate arg supplied to new_from_MBI function";
 }
 
 sub Rmpz_out_str {
@@ -668,7 +680,7 @@ __END__
    eg "1234567890987654321234567" which might be a base 10 number,
    or "zsa34760sdfgq123r5" which would have to represent at least
    a base 36 number (because "z" is a valid digit only in bases 36
-   and higher). Valid bases for GMP numbers are 0 and 2..62 .
+   and higher). Valid bases for GMP numbers are 2..62 .
 
    "$NULL" is $Math::GMPz::NULL (the NULL mpz type).
 
@@ -748,14 +760,14 @@ __END__
    $rop = Math::GMPz::new($arg);
    $rop = new Math::GMPz($arg);
     Returns a Math::GMPz object with the value of $arg.
-    $arg can be either an integer (signed integer, unsigned
-    integer, signed fraction or unsigned fraction) or a string that
-    represents a numeric value. If $arg is a string, an optional
-    additional argument that specifies the base of the number can be
-    supplied to new(). If base is 0 (or not supplied) then the leading
-    characters of the string are used: 0x or 0X for hex, 0b or 0B for
-    binary, 0 for octal, or decimal otherwise. Legal values for the
-    base are 0 and 2..62 .
+    $arg can be either a Math::GMPz object, a Math::BigInt object, a
+    number (signed integer, unsigned integer, signed fraction or
+    unsigned fraction) or a string that represents a numeric value. If
+    $arg is a string, an optional additional argument that specifies
+    the base of the number can be supplied to new(). If base is 0 (or
+    not supplied) then the leading characters of the string are used:
+    0x or 0X for hex, 0b or 0B for binary, 0 for octal, or decimal
+    otherwise. Legal values for the base are 0 and 2..62 .
 
    $rop = Rmpz_init_set($op);
    $rop = Rmpz_init_set_nobless($op);
@@ -768,6 +780,8 @@ __END__
    $rop = Rmpz_init_set_str($str, $base);
    $rop = Rmpz_init_set_str_nobless($str, $base);
 
+   $rop = new_from_MBI($mbi); # $mbi is a Math::BigInt object.
+
    ###################
 
    CONVERTING INTEGERS
@@ -1420,34 +1434,40 @@ __END__
 
    OPERATOR OVERLOADING
 
-    Overloading works with numbers, strings, Math::GMPz objects and, to
-    a limited extent, Math::GMPq objects (iff the gmp library is version
-    6.1.0 or later) and Math::MPFR objects (iff version 3.13 or later of
-    Math::MPFR has been installed).
+    Overloading works with numbers, strings, Math::GMPz objects,
+    Math::BigInt objects and, to a limited extent, Math::GMPq objects
+    (iff the gmp library is version 6.1.0 or later) and Math::MPFR
+    objects (iff version 3.13 or later of Math::MPFR has been
+    installed).
 
    The following operators are overloaded:
-    + - * / %
-    += -= *= /= %=
+    + - * / % **
+    += -= *= /= %= **=
     << >> <<= >>=
     & | ^ ~
     &= |= ^=
     < <= > >= == != <=>
     ! abs
 
+    The "power" operators ('**' and '**=') overload accept only +ve
+    integers (ie +IV or UV). Values that are too large to fit into
+    a C 'unsigned long int' will be silently truncated.
+
     Division uses 'tdiv' (see 'Integer Division', above).
     Check that '~', '%', and '%=' are working as you expect
     (especially in relation to negative values).
 
-    Atempting to use the overloaded operators with objects that
-    have been blessed into some package other than 'Math::GMPz'
-    or 'Math::MPFR' (limited applications) will not work.
+    Attempting to use the overloaded operators with objects that
+    have been blessed into some package other than 'Math::BigInt',
+   'Math::GMPz', 'Math::GMPq' (comparison operators), or 'Math::MPFR'
+    (limited applications) will not work.
     Math::MPFR objects can be used only with '+', '-', '*', '/'
     and '**' operators, and will work only if Math::MPFR is at
     version 3.13 or later - in which case the operation will
     return a Math::MPFR object.
     Math::GMPq objects can be used only with the comparison operators
-    ( == != < <= > >= <=> ), and only if Math::GMPq has been built against
-    gmp-6.1.0 or later.
+    ( == != < <= > >= <=> ), and only if Math::GMPq has been built
+    against gmp-6.1.0 or later.
 
     In those situations where the overload subroutine operates on 2
     perl variables, then obviously one of those perl variables is
@@ -1459,13 +1479,15 @@ __END__
     1. If the variable is an unsigned long then that value is used.
        The variable is considered to be an unsigned long if
        (perl 5.8) the UOK flag is set or if (perl 5.6) SvIsUV()
-       returns true.
+       returns true. (In the case of perls whose ivtype is long long,
+       the variable is treated as an unsigned long long int if the
+       UOK/SvISUV flag is set.)
 
     2. If the variable is a signed long int, then that value is used.
        The variable is considered to be a signed long int if the
-       IOK flag is set. (In the case of perls built with
-       -Duse64bitint, the variable is treated as a signed long long
-       int if the IOK flag is set.)
+       IOK flag is set. (In the case of perls whose ivtype is long long,
+       the variable is treated as a signed long long int if the IOK flag
+       is set.)
 
     3. If the variable is a double, then that value is used. The
        variable is considered to be a double if the NOK flag is set.
